﻿
using Sdl.Core.Settings;
using Sdl.FileTypeSupport.Framework.BilingualApi;
using Sdl.FileTypeSupport.Framework.IntegrationApi;
using Sdl.FileTypeSupport.Framework.NativeApi;


namespace Versacom.Sdl.Plugins.Filters.Demo
{
    /// <summary>
    ///
    /// </summary>
    public class DemoParser : AbstractNativeFileParser, INativeContentCycleAware, ISettingsAware
    {   
        private IPersistentFileConversionProperties fileConversionProperties;
        

        #region AbstractNativeFileParser implementation

        protected override void BeforeParsing()
        {
            this.OnProgress(0);
        }

        /// <summary>
        /// Called while parsing, called until it returns false
        /// </summary>
        /// <returns></returns>
        protected override bool DuringParsing()
        {
            /*
                Trying to parse text like:
                [<First><Second>Some text within second tag</Second></PH></First>Some text after the tags]
            */

            // open structure
            Output.StructureTag(PropertiesFactory.CreateStructureTagProperties("["));

            // some text
            Output.Text(PropertiesFactory.CreateTextProperties("Some text before tags"));

            // open first tag
            IStartTagProperties firstStartTag = PropertiesFactory.CreateStartTagProperties("<First>");
            firstStartTag.SegmentationHint = SegmentationHint.Exclude;
            firstStartTag.DisplayText = "F";
            Output.InlineStartTag(firstStartTag);

            // open second tag
            IStartTagProperties secondStartTag = PropertiesFactory.CreateStartTagProperties("<Second>");
            secondStartTag.SegmentationHint = SegmentationHint.Exclude;
            secondStartTag.DisplayText = "S";
            Output.InlineStartTag(secondStartTag);

            // write some text
            Output.Text(PropertiesFactory.CreateTextProperties("Some text within second tag"));

            // close second tag
            IEndTagProperties secondEndTag = PropertiesFactory.CreateEndTagProperties("</Second>");
            secondEndTag.DisplayText = "S";
            Output.InlineEndTag(secondEndTag);

            // insert a placeholder
            IPlaceholderTagProperties phTag = PropertiesFactory.CreatePlaceholderTagProperties("</PH>");
            phTag.SegmentationHint = SegmentationHint.Exclude;
            phTag.DisplayText = "PH";
            Output.InlinePlaceholderTag(phTag);

            // close first tag
            IEndTagProperties firstEndTag = PropertiesFactory.CreateEndTagProperties("</First>");
            firstEndTag.DisplayText = "F";
            Output.InlineEndTag(firstEndTag);

            // more text --> this wont show up in the editor
            Output.Text(PropertiesFactory.CreateTextProperties("Some text after the tags"));

            // close structure
            Output.StructureTag(PropertiesFactory.CreateStructureTagProperties("]"));

            return false;
        }

        /// <summary>
        /// Called after the parsing is done
        /// </summary>
        protected override void AfterParsing()
        {
            this.OnProgress(100);
        }
        #endregion

               

        #region ISettingsAware members
        /// <summary>
        /// /// <summary>
        /// Implements INativeContentCycleAware.InitializeSettings()
        /// </summary>
        /// </summary>
        /// <param name="settingsBundle"></param>
        /// <param name="configurationId"></param>
        public void InitializeSettings(ISettingsBundle settingsBundle, string configurationId)
        {

            
        }
        #endregion

        #region INativeContentCycleAware
        /// <summary>
        /// Sets the IFileProperties that defines conversion properties
        /// </summary>
        /// <param name="properties"></param>
        public void SetFileProperties(IFileProperties properties)
        {
            this.fileConversionProperties = properties.FileConversionProperties;
        }

        /// <summary>
        /// Implements INativeContentCycleAware.StartOfInput()
        /// </summary>
        public void StartOfInput()
        {
        }

        /// <summary>
        /// Implements INativeContentCycleAware.EndOfInput()
        /// </summary>
        public void EndOfInput()
        {
        }
        #endregion       
    }
}
