﻿using Sdl.FileTypeSupport.Framework.BilingualApi;
using Sdl.FileTypeSupport.Framework.NativeApi;
using System;
using System.IO;
using System.Text;
using Sdl.FileTypeSupport.Framework.IntegrationApi;
using Sdl.Core.Settings;
using System.Windows.Forms;

namespace Versacom.Sdl.Plugins.Filters.Demo
{
    /// <summary>
    /// 
    /// </summary>
    public class DemoWriter : AbstractNativeFileWriter, INativeContentCycleAware, ISettingsAware
    {
        private StreamWriter _target = null;
        private StringBuilder _debugBuilder = new StringBuilder();
        // set by INativeContentCycleAware.SetFileProperties, unused so far
        private IFileProperties _fileProperties = null;
        public override void CustomInfo(ICustomInfoProperties info)
        {
            base.CustomInfo(info);
        }
        
        public override void StructureTag(IStructureTagProperties tagInfo)
        {
            _debugBuilder.Append(tagInfo.TagContent);
            _target.Write(tagInfo.TagContent);
        }

        public override void Text(ITextProperties textInfo)
        {
            if (textInfo.Text != null)
            {
                _debugBuilder.Append(textInfo.Text);
                _target.Write(textInfo.Text);
            }
        }

        public override void InlineStartTag(IStartTagProperties tagInfo)
        {
            _debugBuilder.Append(tagInfo.TagContent);
            _target.Write(tagInfo.TagContent);
        }

        public override void InlineEndTag(IEndTagProperties tagInfo)
        {
            _debugBuilder.Append(tagInfo.TagContent);
            _target.Write(tagInfo.TagContent);
        }
        
        public override void InlinePlaceholderTag(IPlaceholderTagProperties tagInfo)
        {
            _debugBuilder.Append(tagInfo.TagContent);
            _target.Write(tagInfo.TagContent);
        }

        public override void GetProposedOutputFileInfo(IPersistentFileConversionProperties fileProperties, IOutputFileInfo proposedFileInfo)
        {
            proposedFileInfo.Filename = 
                string.Format("{0}_{1}{2}", 
                    Path.GetFileNameWithoutExtension(fileProperties.InputFilePath),
                    fileProperties.TargetLanguage.IsoAbbreviation,
                    Path.GetExtension(fileProperties.InputFilePath));
        }
    
        #region INativeContentCycleAware Members

        /// <summary>
        /// 
        /// </summary>
        public void EndOfInput()
        {
            MessageBox.Show(_debugBuilder.ToString());
            _target.Dispose();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="properties"></param>
        public void SetFileProperties(IFileProperties properties)
        {
            this._fileProperties = properties;
        }

        /// <summary>
        /// 
        /// </summary>
        public void StartOfInput()
        {
            _target = new StreamWriter(OutputProperties.OutputFilePath, false, 
                                       OutputProperties.Encoding.Encoding != null ? OutputProperties.Encoding.Encoding:System.Text.Encoding.UTF8);
        }

        #endregion
       

        public void InitializeSettings(ISettingsBundle settingsBundle, string configurationId)
        {
            
        }
    }
}
